﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;

namespace TestDP
{
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        public static readonly DependencyProperty NumbersDPProperty =
            DependencyProperty.Register(nameof(NumbersDP), typeof(ObservableCollection<int>), typeof(MainWindow), new PropertyMetadata(new ObservableCollection<int>()));

        public MainWindow()
        {
            InitializeComponent();
            MultiLanguage.LanguageChanged += (s, e) =>
            {
                System.Diagnostics.Debug.WriteLine($"Language changed to: {e}");
                RaisePropertyChanged(null);
            };
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public ObservableCollection<int> NumbersDP { get => (ObservableCollection<int>)GetValue(NumbersDPProperty); set => SetValue(NumbersDPProperty, value); }

        public ObservableCollection<int> NumbersNormal { get; } = new ObservableCollection<int>();

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            switch (MultiLanguage.Language)
            {
                case MultiLanguage.Languages.German:
                    MultiLanguage.Language = MultiLanguage.Languages.English;
                    break;

                case MultiLanguage.Languages.English:
                    MultiLanguage.Language = MultiLanguage.Languages.German;
                    break;

                default:
                    break;
            }
        }

        private void RaisePropertyChanged(string propertyName)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}